==> jc-1.4.0.tar.gz: polyglot/types/reflect/ConstantValue.h <==
// class polyglot.types.reflect.ConstantValue

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d931fb91b452174 polyglot_types_reflect_Attribute
// @dep_class 30edde73a378374b polyglot_types_reflect_ConstantValue

// header file dependencies
// @dep_header polyglot_types_reflect_Attribute

#include "polyglot/types/reflect/Attribute.h"

#ifndef _JC_polyglot_types_reflect_ConstantValue_H_
#define _JC_polyglot_types_reflect_ConstantValue_H_

// Forward structure declarations
struct _jc_java_io_DataInputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_types_reflect_ConstantValue$sub_refs	_jc_polyglot_types_reflect_ConstantValue$sub_refs;
typedef struct _jc_polyglot_types_reflect_ConstantValue$sub_nonrefs	_jc_polyglot_types_reflect_ConstantValue$sub_nonrefs;
typedef struct _jc_polyglot_types_reflect_ConstantValue$refs	_jc_polyglot_types_reflect_ConstantValue$refs;
typedef struct _jc_polyglot_types_reflect_ConstantValue$nonrefs	_jc_polyglot_types_reflect_ConstantValue$nonrefs;
typedef struct _jc_polyglot_types_reflect_ConstantValue$object	_jc_polyglot_types_reflect_ConstantValue$object;

typedef const struct _jc_polyglot_types_reflect_ConstantValue$vmethods	_jc_polyglot_types_reflect_ConstantValue$vmethods;
typedef const struct _jc_polyglot_types_reflect_ConstantValue$vtable	_jc_polyglot_types_reflect_ConstantValue$vtable;
typedef const struct _jc_polyglot_types_reflect_ConstantValue$vtype	_jc_polyglot_types_reflect_ConstantValue$vtype;

// Constructors
extern void _jc_polyglot_types_reflect_ConstantValue$method$_init$f7ce785ea6b7867d(_jc_env *, struct _jc_polyglot_types_reflect_ConstantValue$object *, struct _jc_java_io_DataInputStream$object *, jint, jint);

// Virtual methods structure
struct _jc_polyglot_types_reflect_ConstantValue$vmethods {
};

// Vtable
struct _jc_polyglot_types_reflect_ConstantValue$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_reflect_Attribute$vmethods	polyglot_types_reflect_Attribute;
	_jc_polyglot_types_reflect_ConstantValue$vmethods	polyglot_types_reflect_ConstantValue;
};

// Vtype
struct _jc_polyglot_types_reflect_ConstantValue$vtype {
	_jc_type			type;
	_jc_polyglot_types_reflect_ConstantValue$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_reflect_ConstantValue$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_types_reflect_ConstantValue$refs {
    _jc_polyglot_types_reflect_ConstantValue$sub_refs	polyglot_types_reflect_ConstantValue;
    _jc_polyglot_types_reflect_Attribute$sub_refs	polyglot_types_reflect_Attribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_reflect_ConstantValue$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_reflect_ConstantValue$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_reflect_Attribute$sub_nonrefs	polyglot_types_reflect_Attribute;
    _jc_polyglot_types_reflect_ConstantValue$sub_nonrefs	polyglot_types_reflect_ConstantValue;
};

// Object instance structure
struct _jc_polyglot_types_reflect_ConstantValue$object {
	_jc_polyglot_types_reflect_ConstantValue$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_reflect_ConstantValue$vtype	*vtype;
	_jc_polyglot_types_reflect_ConstantValue$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_reflect_ConstantValue$vtype _jc_polyglot_types_reflect_ConstantValue$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_reflect_ConstantValue, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_reflect_ConstantValue$class_object;

#endif	/* _JC_polyglot_types_reflect_ConstantValue_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/reflect/ConstantValue.h <==
// class polyglot.types.reflect.ConstantValue

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d931fb91b452174 polyglot_types_reflect_Attribute
// @dep_class 30edde73a378374b polyglot_types_reflect_ConstantValue

// header file dependencies
// @dep_header polyglot_types_reflect_Attribute

#include "polyglot/types/reflect/Attribute.h"

#ifndef _JC_polyglot_types_reflect_ConstantValue_H_
#define _JC_polyglot_types_reflect_ConstantValue_H_

// Forward structure declarations
struct _jc_java_io_DataInputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_types_reflect_ConstantValue$sub_refs	_jc_polyglot_types_reflect_ConstantValue$sub_refs;
typedef struct _jc_polyglot_types_reflect_ConstantValue$sub_nonrefs	_jc_polyglot_types_reflect_ConstantValue$sub_nonrefs;
typedef struct _jc_polyglot_types_reflect_ConstantValue$refs	_jc_polyglot_types_reflect_ConstantValue$refs;
typedef struct _jc_polyglot_types_reflect_ConstantValue$nonrefs	_jc_polyglot_types_reflect_ConstantValue$nonrefs;
typedef struct _jc_polyglot_types_reflect_ConstantValue$object	_jc_polyglot_types_reflect_ConstantValue$object;

typedef const struct _jc_polyglot_types_reflect_ConstantValue$vmethods	_jc_polyglot_types_reflect_ConstantValue$vmethods;
typedef const struct _jc_polyglot_types_reflect_ConstantValue$vtable	_jc_polyglot_types_reflect_ConstantValue$vtable;
typedef const struct _jc_polyglot_types_reflect_ConstantValue$vtype	_jc_polyglot_types_reflect_ConstantValue$vtype;

// Constructors
extern void _jc_polyglot_types_reflect_ConstantValue$method$_init$f7ce785ea6b7867d(_jc_env *, struct _jc_polyglot_types_reflect_ConstantValue$object *, struct _jc_java_io_DataInputStream$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_types_reflect_ConstantValue$vmethods {
};

// Vtable
struct _jc_polyglot_types_reflect_ConstantValue$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_reflect_Attribute$vmethods	polyglot_types_reflect_Attribute;
	_jc_polyglot_types_reflect_ConstantValue$vmethods	polyglot_types_reflect_ConstantValue;
};

// Vtype
struct _jc_polyglot_types_reflect_ConstantValue$vtype {
	_jc_type			type;
	_jc_polyglot_types_reflect_ConstantValue$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_reflect_ConstantValue$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_types_reflect_ConstantValue$refs {
    _jc_polyglot_types_reflect_ConstantValue$sub_refs	polyglot_types_reflect_ConstantValue;
    _jc_polyglot_types_reflect_Attribute$sub_refs	polyglot_types_reflect_Attribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_reflect_ConstantValue$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_reflect_ConstantValue$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_reflect_Attribute$sub_nonrefs	polyglot_types_reflect_Attribute;
    _jc_polyglot_types_reflect_ConstantValue$sub_nonrefs	polyglot_types_reflect_ConstantValue;
};

// Object instance structure
struct _jc_polyglot_types_reflect_ConstantValue$object {
	_jc_polyglot_types_reflect_ConstantValue$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_reflect_ConstantValue$vtype	*vtype;
	_jc_polyglot_types_reflect_ConstantValue$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_reflect_ConstantValue$vtype _jc_polyglot_types_reflect_ConstantValue$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_reflect_ConstantValue, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_reflect_ConstantValue$class_object;

#endif	/* _JC_polyglot_types_reflect_ConstantValue_H_ */
